==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/nl/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "Meer Info",

    "audit_help" => "Als u dit selectievakje aanvinkt, wordt het asset record bewerkt om deze nieuwe locatie te weerspiegelen. Als u het uitgevinkt laat staan ziet u de locatie in het audit logboek.<br><br>Let op dat als dit asset is uitgecheckt, dan zal de locatie van de persoon, product of locatie waar het uitgecheckt is niet veranderen.",

    'assets' => 'Assets bestaan uit items die met een serienummer of identificatiesticker geregistreerd zijn. Dit zijn over het algemeen de objecten met een hogere waarde waarbij identificatie belangrijk is.',

    'categories' => 'Categorieën helpen je om je items te organiseren. Een aantal voorbeeld categorieën zijn &quot;Desktops&quot;, &quot;Laptops&quot;, &quot;Mobiele telefoons&quot;, &quot;Tablets&quot;enzovoort, maar je kan categorieën gebruiken op een voor jou logische manier.',

    'accessories' => 'Accessoires zijn alles wat je uitgeeft aan gebruikers, maar die geen serienummer hebben (of u maakt het niet uit om ze uniek te volgen). Bijvoorbeeld computermuizen of toetsenborden.',

    'companies'     => 'Bedrijven kunnen worden gebruikt als een eenvoudig identificatieveld of kunnen worden gebruikt om de zichtbaarheid van assets, gebruikers, etc te beperken als volledige bedrijfsondersteuning is ingeschakeld in uw Admin instellingen.',

    'components'    => 'Componenten zijn onderdelen van een asset zoals een harde schijf, geheugen, etc.',

    'consumables'   => 'Verbruiksartikelen zijn alles wat gekocht is en wat na verloop van tijd opraakt. Bijvoorbeeld printer inkt of kopieer papier.',

    'depreciations' => 'Je kunt de asset-afschrijving instellen om assets af te schrijven op basis van lineaire afschrijving.',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/nl/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'Meer Info',

    'audit_help' => 'Als u dit selectievakje aanvinkt, wordt het asset record bewerkt om deze nieuwe locatie te weerspiegelen. Als u het uitgevinkt laat staan ziet u de locatie in het audit logboek.<br><br>Let op dat als dit asset is uitgecheckt, dan zal de locatie van de persoon, product of locatie waar het uitgecheckt is niet veranderen.',

    'assets' => 'Assets bestaan uit items die met een serienummer of identificatiesticker geregistreerd zijn. Dit zijn over het algemeen de objecten met een hogere waarde waarbij identificatie belangrijk is.',

    'categories' => 'Categorieën helpen je om je items te organiseren. Een aantal voorbeeld categorieën zijn &quot;Desktops&quot;, &quot;Laptops&quot;, &quot;Mobiele telefoons&quot;, &quot;Tablets&quot;enzovoort, maar je kan categorieën gebruiken op een voor jou logische manier.',

    'accessories' => 'Accessoires zijn alles wat je uitgeeft aan gebruikers, maar die geen serienummer hebben (of u maakt het niet uit om ze uniek te volgen). Bijvoorbeeld computermuizen of toetsenborden.',

    'companies'     => 'Bedrijven kunnen worden gebruikt als een eenvoudig identificatieveld of kunnen worden gebruikt om de zichtbaarheid van assets, gebruikers, etc te beperken als volledige bedrijfsondersteuning is ingeschakeld in uw Admin instellingen.',

    'components'    => 'Componenten zijn onderdelen van een asset zoals een harde schijf, geheugen, etc.',

    'consumables'   => 'Verbruiksartikelen zijn alles wat gekocht is en wat na verloop van tijd opraakt. Bijvoorbeeld printer inkt of kopieer papier.',

    'depreciations' => 'Je kunt de asset-afschrijving instellen om assets af te schrijven op basis van lineaire afschrijving.',

];
